@@ -1,6 +1,7 @@
 pub mod env;
 pub mod routine;
 pub mod arch;
+pub mod ir;
 
 pub use env::*;
 pub use routine::*;
@@ -130,4 +131,17 @@ mod tests {
             Err(err) => panic!("{}", err.to_string())
         };
     }
+
+    #[test]
+    fn test_split() {
+        assert_eq!(ir::split("a b c"), vec!["a", "b", "c"]);
+    }
+
+    #[test]
+    fn test_parse() {
+        assert_eq!(match ir::parse("1 2 3") {
+            Ok(ok) => ok,
+            Err(err) => panic!("{}", err.to_string())
+        }, vec![1, 2, 3]);
+    }
 }
